package FBP::Spacer;

use Mouse;

our $VERSION = '0.05';

extends 'FBP::Object';

1;
